| Copyright | (c) 2018 Francisco Vallarino |
|---|---|
| License | BSD-3-Clause (see the LICENSE file) |
| Maintainer | fjvallarino@gmail.com |
| Stability | experimental |
| Portability | non-portable |
| Safe Haskell | None |
| Language | Haskell2010 |
Monomer.Widgets.Containers.Alert
Description
Simple alert dialog, displaying a close button and optional title. Usually embedded in a zstack component and displayed/hidden depending on context.
Config:
- titleCaption: the title of the alert dialog.
- closeCaption: the caption of the close button.
Synopsis
- alert :: (WidgetModel sp, WidgetEvent ep) => ep -> WidgetNode () ep -> WidgetNode sp ep
- alert_ :: (WidgetModel sp, WidgetEvent ep) => ep -> [AlertCfg] -> WidgetNode () ep -> WidgetNode sp ep
- alertMsg :: (WidgetModel sp, WidgetEvent ep) => Text -> ep -> WidgetNode sp ep
- alertMsg_ :: (WidgetModel sp, WidgetEvent ep) => Text -> ep -> [AlertCfg] -> WidgetNode sp ep
Documentation
Arguments
| :: (WidgetModel sp, WidgetEvent ep) | |
| => ep | The event to raise when the dialog is closed. |
| -> WidgetNode () ep | The content to display in the dialog. |
| -> WidgetNode sp ep | The created dialog. |
Creates an alert dialog with the provided content.
Arguments
| :: (WidgetModel sp, WidgetEvent ep) | |
| => ep | The event to raise when the dialog is closed. |
| -> [AlertCfg] | The config options for the dialog. |
| -> WidgetNode () ep | The content to display in the dialog. |
| -> WidgetNode sp ep | The created dialog. |
Creates an alert dialog with the provided content. Accepts config.
Arguments
| :: (WidgetModel sp, WidgetEvent ep) | |
| => Text | The message to display. |
| -> ep | The event to raise when the dialog is closed. |
| -> WidgetNode sp ep | The created dialog. |
Creates an alert dialog with a text message as content.
Arguments
| :: (WidgetModel sp, WidgetEvent ep) | |
| => Text | The message to display. |
| -> ep | The event to raise when the dialog is closed. |
| -> [AlertCfg] | The config options for the dialog. |
| -> WidgetNode sp ep | The created dialog. |
Creates an alert dialog with a text message as content. Accepts config.